# Edit this configuration file to define what should be installed on
# your system.  Help is available in the configuration.nix(5) man page
# and in the NixOS manual (accessible by running ‘nixos-help’).

{ config, pkgs, ... }:

{
  imports =
    [ # Include the results of the hardware scan.
      ./hardware-configuration.nix
      ../../../desktop
      ../../../desktop/dev.nix
      ../../../desktop/office.nix
      ../../../ops
      ../../../users/owners.nix
    ];

  networking.hostName = "valhalla"; # Define your hostname.
  # networking.wireless.enable = true;  # Enables wireless support via wpa_supplicant.

  # Bootloader.
  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;


  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "23.11"; # Did you read the comment?

  # Automatic Garbage Collection
  nix.gc = {
               automatic = true;
               dates   = "weekly";
               options = "--delete-older-than 14d";
  };
  # Auto system update
  system.autoUpgrade = {
     enable = true;
  };


  fileSystems."/var/lib/docker" = {
    device = "/home/docker";
    options = [ "bind" ];
  };


}
